/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.beans.IntrospectionException;
import java.util.List;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Genus;
import nl.cloudfarming.client.crop.model.Variety;
import org.openide.nodes.*;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class CropDefinitionNode extends BeanNode<CropDefinition> {

    public CropDefinitionNode(CropDefinition bean) throws IntrospectionException {
        super(bean, new CropDefinitionChildren(bean));
    }

    private static class CropDefinitionChildren extends Children.Keys<CropDefinition>{
        public CropDefinitionChildren(CropDefinition bean) {
            setKeys(new CropDefinition[]{bean});
            addNotify();
        }

        @Override
        protected Node[] createNodes(CropDefinition key) {
            return new Node[]{new GeneraNode(key.getGenera()), new VarietiesNode(key.getVarieties())};
        }
    }
    
    @NbBundle.Messages("GeneraNode.name=Genera")
    private static class GeneraNode extends AbstractNode{

        public GeneraNode(List<Genus> genera) {
            super(Children.create(new GeneraChildFactory(genera), true));
            setName(Bundle.GeneraNode_name());
        }
    }
    
    private static class GeneraChildFactory extends ChildFactory<Genus>{

        private final List<Genus> genera;

        public GeneraChildFactory(List<Genus> genera) {
            this.genera = genera;
        }
        
        @Override
        protected boolean createKeys(List<Genus> toPopulate) {
            toPopulate.addAll(this.genera);
            return true;
        }

        @Override
        protected Node createNodeForKey(Genus key) {
            try {
                return new GenusNode(key);
            } catch (IntrospectionException ex) {
                Exceptions.printStackTrace(ex);
                return null;
            }
        }
    }
    
    @NbBundle.Messages("VarietyNode.name=Varieties")
    private static class VarietiesNode extends AbstractNode{

        public VarietiesNode(List<Variety> varieties) {
            super(Children.create(new VarietyChildFactory(varieties), true));
            setName(Bundle.VarietyNode_name());
        }
    }
    
    private static class VarietyChildFactory extends ChildFactory<Variety>{

        private final List<Variety> varieties;

        public VarietyChildFactory(List<Variety> varieties) {
            this.varieties = varieties;
        }
        
        @Override
        protected boolean createKeys(List<Variety> toPopulate) {
            toPopulate.addAll(this.varieties);
            return true;
        }

        @Override
        protected Node createNodeForKey(Variety key) {
            try {
                return new VarietyNode(key);
            } catch (IntrospectionException ex) {
                Exceptions.printStackTrace(ex);
                return null;
            }
        }
    }    
}
