/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.stock.project.StockProject;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@MultiViewElement.Registration(displayName = "#LBL_Crop_VISUAL",
iconBase = "nl/cloudfarming/client/stock/project/visual/box.png",
mimeType = StockProject.MIME_TYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "CropVisual",
position = 2000)
@NbBundle.Messages({"LBL_Crop_VISUAL=Crop list"})
public class CropListVisualElement implements MultiViewElement {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.stock.crop.CropListVisualElement");
    private static final String CROP_FOLDER = "crops";
    private transient MultiViewElementCallback callback;
    private JToolBar toolbar = new JToolBar();
    private Lookup lookup;
    private final CropListVisualPanel content;
    private final ASBodyPanel wrappedContent;

    public CropListVisualElement(Lookup lkp) throws IOException {
        lookup = lkp;
        Project p = lookup.lookup(Project.class);
        assert p != null:"Lookup did not contain a stock project";
        FileObject cropsFolder = getCropFolder(p.getProjectDirectory(), true);

        CropStorage cropStorage = CropStorageManager.load(cropsFolder);
        
        content = new CropListVisualPanel(cropStorage);
        wrappedContent = new ASBodyPanel(content);

        //FIXME set icon and name
        wrappedContent.setName(Bundle.LBL_Crop_VISUAL());
//        wrappedContent.setIcon(null);
    }

    @Override
    public JComponent getVisualRepresentation() {
        return wrappedContent;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[]{};
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    private void updateName() {
        if (callback != null) {
            String name = Bundle.LBL_Crop_VISUAL();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    private FileObject getCropFolder(FileObject projectRoot, boolean create) throws IOException {
        FileObject cropFolder = projectRoot.getFileObject(CROP_FOLDER);
        if (cropFolder == null && create) {
            LOGGER.log(Level.FINEST, "Crop folder {0} did not exist, creating now.", CROP_FOLDER);
            cropFolder = projectRoot.createFolder(CROP_FOLDER);
        }
        if (cropFolder != null && !cropFolder.isFolder()) {
            LOGGER.log(Level.SEVERE, "crop folder {0} is not a folder, probably a file.", CROP_FOLDER);
            cropFolder = null;
        }
        return cropFolder;
    }
}
