/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.beans.IntrospectionException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Genus;
import nl.cloudfarming.client.crop.model.Variety;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.explorer.ExplorerManager;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class CropStorage implements Serializable, ExplorerManager.Provider {

    private static final long serialVersionUID = 1L;
    public static final String TYPE = "nl-cloudfarming-client-stock-crop";
    private final ExplorerManager explorerManager = new ExplorerManager();

    public CropStorage() {
        explorerManager.setRootContext(new CropsRootNode());
    }

    @Override
    public ExplorerManager getExplorerManager() {
        return explorerManager;
    }

    private class CropsRootNode extends AbstractNode {

        public CropsRootNode() {
            super(Children.create(new CropsChildFactory(), true));
        }
    }

    private static class CropsChildFactory extends ChildFactory<CropDefinition> {

        public CropsChildFactory() {
        }

        @Override
        protected boolean createKeys(List<CropDefinition> toPopulate) {

            List<Variety> varieties = new ArrayList<>();
            varieties.add(new Variety("V1"));
            varieties.add(new Variety("V2"));
            varieties.add(new Variety("V3"));

            List<Genus> gena = new ArrayList<>();
            gena.add(new Genus("A"));
            gena.add(new Genus("B"));
            gena.add(new Genus("C"));


            List<Variety> varieties2 = new ArrayList<>();
            varieties2.add(new Variety("1111111111111111"));
            varieties2.add(new Variety("2222222222222222"));

            List<Genus> gena2 = new ArrayList<>();
            gena2.add(new Genus("Aaaaaaaaaaaaa"));
            gena2.add(new Genus("Bbbbbbbbbbbbb"));

            toPopulate.add(new CropDefinition("dummy", varieties, gena));
            toPopulate.add(new CropDefinition("dummy2", varieties2, gena2));
            toPopulate.add(new CropDefinition("dummy", varieties, gena));
            toPopulate.add(new CropDefinition("dummy2", varieties2, gena2));
            
            return true;
        }

        @Override
        protected Node createNodeForKey(CropDefinition key) {
            try {
                return new CropDefinitionNode(key);
            } catch (IntrospectionException ex) {
                Exceptions.printStackTrace(ex);
                return null;
            }
        }
        
        
    }
}
